@@ -6,8 +6,8 @@
  *
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2012, kitone
  *
@@ -235,7 +235,7 @@ protected:
 
 			prevend = intime + dur;
 		}
-		//reset the end time of the last subtitle to make sure rouding errors didn't move it
+		//reset the end time of the last subtitle to make sure rounding errors didn't move it
 		subtitles.back().set_end( endtime );
 	}
 
