@@ -4,8 +4,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2015, kitone
  *
@@ -72,7 +72,7 @@ public:
 	 */
 	static void create(Gtk::Window &parent, std::vector<ErrorChecking*> &list)
 	{
-		std::auto_ptr<DialogErrorCheckingPreferences> dialog(
+		std::unique_ptr<DialogErrorCheckingPreferences> dialog(
 				gtkmm_utility::get_widget_derived<DialogErrorCheckingPreferences>(
 					SE_DEV_VALUE(SE_PLUGIN_PATH_UI, SE_PLUGIN_PATH_DEV),
 					"dialog-error-checking-preferences.ui", 
