@@ -1,8 +1,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2012, kitone
  *
@@ -212,7 +212,7 @@ public:
 			std::cerr << "FindAndReplacePlugin::Exception : " << ex.what() << std::endl;
 			return false;
 		}
-		// update lenght of info
+		// update length of info
 		info.len = replacement.size();
 
 		doc.start_command(_("Replace text"));
