@@ -1,8 +1,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2015, kitone
  *
@@ -180,7 +180,7 @@ protected:
 		g_return_val_if_fail(doc, false);
 
 		// create dialog
-		std::auto_ptr<DialogMoveSubtitles> dialog(
+		std::unique_ptr<DialogMoveSubtitles> dialog(
 				gtkmm_utility::get_widget_derived<DialogMoveSubtitles>(
 						SE_DEV_VALUE(SE_PLUGIN_PATH_UI, SE_PLUGIN_PATH_DEV),
 						"dialog-move-subtitles.ui", 
