@@ -1,8 +1,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2009, kitone
  *
@@ -67,7 +67,7 @@ public:
 	 */
 	static void create()
 	{
-		std::auto_ptr<DialogPreferences> dialog(
+		std::unique_ptr<DialogPreferences> dialog(
 				gtkmm_utility::get_widget_derived<DialogPreferences>(
 						SE_DEV_VALUE(SE_PLUGIN_PATH_UI, SE_PLUGIN_PATH_DEV),
 						"dialog-preferences.ui", 
