@@ -1,8 +1,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2015, kitone
  *
@@ -488,7 +488,7 @@ protected:
 		g_return_if_fail(doc);
 
 		// create dialog
-		std::auto_ptr<DialogStyleEditor> dialog(
+		std::unique_ptr<DialogStyleEditor> dialog(
 				gtkmm_utility::get_widget_derived<DialogStyleEditor>(
 						SE_DEV_VALUE(SE_PLUGIN_PATH_UI, SE_PLUGIN_PATH_DEV),
 						"dialog-style-editor.ui", 
