@@ -4,8 +4,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2009, kitone
  *
@@ -219,7 +219,7 @@ public:
 		m_treeview = manage(new Gtk::TreeView);
 		scrolled->add(*m_treeview);
 
-		// Box for Script, Language and Contry combobox
+		// Box for Script, Language and Country combobox
 		Gtk::Label* wlabel = NULL;
 
 		Gtk::Table* table = manage(new Gtk::Table(3,2, false));
