@@ -1,8 +1,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2015, kitone
  *
@@ -44,7 +44,7 @@ public:
 
 	static void create()
 	{
-		std::auto_ptr<DialogTimingFromPlayerPreferences> dialog(
+		std::unique_ptr<DialogTimingFromPlayerPreferences> dialog(
 				gtkmm_utility::get_widget_derived<DialogTimingFromPlayerPreferences>(
 						SE_DEV_VALUE(SE_PLUGIN_PATH_UI, SE_PLUGIN_PATH_DEV),
 						"dialog-timing-from-player-preferences.ui", 
@@ -135,7 +135,7 @@ public:
 					_("Use the current player position to set the end of the current selected subtitle and the position of the next")), 
 					sigc::mem_fun(*this, &TimingFromPlayer::set_subtitle_end_and_next));
 
-		// set current subtile start and and with one key
+		// set current subtile start and with one key
 		action_group->add(
 				Gtk::Action::create(
 					"timing-from-player/set-subtitle-start-and-end-with-one-key", 
