@@ -1,8 +1,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2015, kitone
  *
@@ -20,9 +20,9 @@
  *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <iomanip>
 #include <extension/subtitleformat.h>
 #include <utility.h>
-#include <iomanip>
 #include <cstdio>
 #include <document.h>
 #include <gtkmm_utility.h>
@@ -101,7 +101,7 @@ public:
 	 */
 	static void create()
 	{
-		std::auto_ptr<DialogAdvancedSubStationAlphaPreferences> dialog(
+		std::unique_ptr<DialogAdvancedSubStationAlphaPreferences> dialog(
 				gtkmm_utility::get_widget_derived<DialogAdvancedSubStationAlphaPreferences>(
 						SE_DEV_VALUE(SE_PLUGIN_PATH_UI, SE_PLUGIN_PATH_DEV),
 						"dialog-advancedsubstationalpha-preferences.ui", 
@@ -360,7 +360,7 @@ public:
 			Glib::ustring::compose(
 				"[Script Info]\n"
 				"; This script was created by subtitleeditor (%1)\n"
-				"; http://home.gna.org/subtitleeditor/\n",
+				"; https://kitone.github.io/subtitleeditor/\n",
 				Glib::ustring(VERSION)));
 
 		ScriptInfo& scriptInfo = document()->get_script_info();
