@@ -1,8 +1,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2009, kitone
  *
@@ -85,7 +85,6 @@ void get_default_config(std::map<Glib::ustring, std::map<Glib::ustring, Glib::us
 	config["interface"]["create-backup-copy"] = "false";
 	config["interface"]["autosave-minutes"] = "10";
 	config["interface"]["max-undo"] = "20";
-	config["interface"]["do-auto-timing-check"] = "true";
 
 	//[encodings]
 	config["encodings"]["encodings"] = "ISO-8859-15;UTF-8";
@@ -109,6 +108,7 @@ void get_default_config(std::map<Glib::ustring, std::map<Glib::ustring, Glib::us
 	config["timing"]["max-characters-per-line"] = "40";
 	config["timing"]["max-line-per-subtitle"] = "2";
 	config["timing"]["ignore-space"] = "false";
+	config["timing"]["do-auto-timing-check"] = "true";
 
 	//[external-video-player]
 	config["external-video-player"]["command"] = "mplayer \"#video_file\" -noautosub -sub \"#subtitle_file\" -ss #seconds -osdlevel 2";
