@@ -1,8 +1,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2012, kitone
  *
@@ -823,7 +823,7 @@ void Application::load_window_state()
 	Config &cfg = Config::getInstance();
 
 	// window size,position
-	if(cfg.get_value_bool("interface", "window-maximized"))
+	if(cfg.get_value_bool("interface", "maximize-window"))
 		maximize();
 	else
 	{
