@@ -1,8 +1,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2009, kitone
  *
@@ -173,7 +173,7 @@ void ComboBoxEncoding::on_combo_changed()
 
 	if(activated == size-1)
 	{
-		std::auto_ptr<DialogCharacterCodings> dialog = DialogCharacterCodings::create(*dynamic_cast<Gtk::Window*>(get_toplevel()));
+		std::unique_ptr<DialogCharacterCodings> dialog = DialogCharacterCodings::create(*dynamic_cast<Gtk::Window*>(get_toplevel()));
 		if(dialog->run() == Gtk::RESPONSE_OK)
 		{
 			init_encodings();
