@@ -4,8 +4,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2009, kitone
  *
@@ -58,7 +58,7 @@ public:
 	 * Create an instance of the dialog .ui file)
 	 * If the response is OK the config is saved.
 	 */
-	static std::auto_ptr<DialogCharacterCodings> create(Gtk::Window &parent);
+	static std::unique_ptr<DialogCharacterCodings> create(Gtk::Window &parent);
 
 protected:
 
