@@ -4,8 +4,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2010, kitone
  *
@@ -91,6 +91,8 @@ public:
 	SubtitleTime operator+(const SubtitleTime &b) const;
 	SubtitleTime operator*(const double &mult) const;
 	double operator/(const SubtitleTime &b) const;
+	SubtitleTime operator/(const double &div) const;
+	SubtitleTime operator/(const long &div) const;
 
 	bool operator==(const SubtitleTime &time) const;
 	bool operator!=(const SubtitleTime &time) const;
