@@ -1,8 +1,8 @@
 /*
  *	subtitleeditor -- a tool to create or edit subtitle
  *
- *	http://home.gna.org/subtitleeditor/
- *	https://gna.org/projects/subtitleeditor/
+ *	https://kitone.github.io/subtitleeditor/
+ *	https://github.com/kitone/subtitleeditor/
  *
  *	Copyright @ 2005-2014, kitone
  *
@@ -343,7 +343,7 @@ void GstPlayer::set_repeat(bool state)
 }
 
 /*
- * Realize the widget and get the the xWindowId.
+ * Realize the widget and get the xWindowId.
  */
 void GstPlayer::on_realize()
 {
@@ -417,8 +417,11 @@ Glib::RefPtr<Gst::Element> GstPlayer::gen_audio_element()
 	}
 	catch(std::runtime_error &ex)
 	{
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-security"
 		se_debug_message(SE_DEBUG_VIDEO_PLAYER, "failed to gen_audio_element '%s'", ex.what());
 		GST_ELEMENT_WARNING(m_pipeline->gobj(), RESOURCE, NOT_FOUND, (ex.what()), (NULL));
+#pragma GCC diagnostic pop
 	}
 	// Return an NULL ptr
 	return Glib::RefPtr<Gst::Element>();
@@ -507,8 +510,11 @@ Glib::RefPtr<Gst::Element> GstPlayer::gen_video_element()
 	}
 	catch(std::runtime_error &ex)
 	{
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-security"
 		se_debug_message(SE_DEBUG_VIDEO_PLAYER, "failed to gen_video_element '%s'", ex.what());
 		GST_ELEMENT_ERROR(m_pipeline->gobj(), RESOURCE, NOT_FOUND, (ex.what()), (NULL));
+#pragma GCC diagnostic pop
 	}
 	// Return an NULL ptr
 	return Glib::RefPtr<Gst::Element>();
@@ -692,7 +698,7 @@ void GstPlayer::on_bus_message_element(const Glib::RefPtr<Gst::MessageElement> &
 
 /*
  * An error is detected. 
- * Detroy the pipeline and show the error message in a dialog.
+ * Destroy the pipeline and show the error message in a dialog.
  */
 void GstPlayer::on_bus_message_error(const Glib::RefPtr<Gst::MessageError> &msg)
 {
@@ -781,7 +787,7 @@ void GstPlayer::on_bus_message_state_changed(const Glib::RefPtr<Gst::MessageStat
 /*
  * End-of-stream (segment or stream) has been detected, 
  * update the pipeline state to PAUSED.
- * Seek to the begining if it's the end of the stream.
+ * Seek to the beginning if it's the end of the stream.
  */
 void GstPlayer::on_bus_message_eos(const Glib::RefPtr<Gst::MessageEos> &/*msg*/)
 {
